﻿using System;
using System.Collections.ObjectModel;
using System.Linq;
using System.Net;
using System.Text.RegularExpressions;
using System.Windows;
using System.Windows.Controls;
using System.Windows.Documents;
using System.Windows.Ink;
using System.Windows.Input;
using System.Windows.Media;
using System.Windows.Media.Animation;
using System.Windows.Shapes;
using Infragistics.Controls.Editors;

namespace CustomComboEditorColumn
{
    public class AttributeViewModel : NotifyDataErrorInfoViewModelBase
    {
        #region Fields

        private AttributeModel m_Attribute;

        #endregion Fields


        #region Properties

        public string Name
        {
            get
            {
                return m_Attribute.Name;
            }
        }

        public ObservableCollection<ValueModel> Values
        {
            get
            {
                return m_Attribute.SuggestedValues;
            }
        }



        public ValueModel SelectedValue
        {
            get
            {
                return _SelectedValue;
            }
            set
            {
                if (m_Attribute.Value != value)
                {
                    if (value != null)
                    {
                        if (IsValid(value))
                        {
                            m_Attribute.Value = value;
                            _SelectedValue = Values.FirstOrDefault(val => val.ValueDescription == m_Attribute.Value.ValueDescription);
                        }
                        else
                        {
                            _SelectedValue = new ValueModel("ErsatzValue");
                            Values.Insert(0, _SelectedValue);
                            //_SelectedValue = null;
                            //Values.Remove(value);
                        }
                    }
                    else //delete value
                    {
                        RemoveErrorsForProperty("SelectedValue");
                        m_Attribute.Value = null;
                        _SelectedValue = null;
                    }

                    OnNotifyPropertyChanged("SelectedValue");
                }
            }
        }


        private ValueModel _SelectedValue;

        #endregion Properties


        #region Constructor

        public AttributeViewModel() { }

        public AttributeViewModel(AttributeModel attribute)
        {
            m_Attribute = attribute;
            _SelectedValue = Values.FirstOrDefault(val => val.ValueDescription == m_Attribute.Value.ValueDescription);
        }

        #endregion Constructor



        //min 2 alphanumerics 
        private static readonly Regex _AlphaNumericRegex = new Regex(@"^[a-zA-Z][a-zA-Z]+$");

        //min 1 number
        private static readonly Regex _NumberRegex = new Regex(@"^\d+$");

        private bool IsValid(ValueModel value)
        {
            string errorText = null;

            if ((m_Attribute.Name == "CompanyName") || (m_Attribute.Name == "Location") || (m_Attribute.Name == "Material"))
            {
                if (!_AlphaNumericRegex.IsMatch(value.ValueDescription))
                {
                    errorText = "Not a string!";
                }
            }

            if ((m_Attribute.Name == "Height") || (m_Attribute.Name == "Width"))
            {
                if (!_NumberRegex.IsMatch(value.ValueDescription))
                {
                    errorText = "Not a Number";
                }
            }

            if (!string.IsNullOrEmpty(errorText))
            {
                AddErrorForProperty("SelectedValue", errorText);
                MessageBox.Show(errorText);
                return false;
            }
            else
            {
                RemoveErrorsForProperty("SelectedValue");
            }

            return true;
        }

    }
}
